# Beanclerk

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/peberanek/beanclerk/main.svg)](https://results.pre-commit.ci/latest/github/peberanek/beanclerk/main)

Additional automation for [Beancount](https://github.com/beancount/beancount)

## Contributing

Set up a development environment:
```bash
./build_venv
source venv/bin/activate
pre-commit install  # https://pre-commit.com/
```

Follow [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/).

Run tests:
```bash
pytest
```
